@@ -5,6 +5,8 @@
 */
 
 #include "sylpheedaddressbook.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <KContacts/Addressee>
 #include <KContacts/ContactGroup>
 
@@ -22,12 +24,12 @@ SylpheedAddressBook::~SylpheedAddressBook() = default;
 
 void SylpheedAddressBook::importAddressBook()
 {
-    const QStringList files = mDir.entryList(QStringList(QStringLiteral("addrbook-[0-9]*.xml")), QDir::Files, QDir::Name);
+    const QStringList files = mDir.entryList(QStringList(u"addrbook-[0-9]*.xml"_s), QDir::Files, QDir::Name);
     if (files.isEmpty()) {
         addAddressBookImportInfo(i18n("No addressbook found"));
     } else {
         for (const QString &file : files) {
-            readAddressBook(mDir.path() + QLatin1Char('/') + file);
+            readAddressBook(mDir.path() + u'/' + file);
         }
     }
     cleanUp();
@@ -62,27 +64,27 @@ void SylpheedAddressBook::readAddressBook(const QString &filename)
     }
 
     for (; !e.isNull(); e = e.nextSiblingElement()) {
-        // TODO ?? const QString name = e.attribute(QStringLiteral("name"));
+        // TODO ?? const QString name = e.attribute(u"name"_s);
 
         const QString tag = e.tagName();
         if (tag == QLatin1StringView("person")) {
             KContacts::Addressee contact;
             // uid="333304265" first-name="dd" last-name="ccc" nick-name="" cn="laurent"
             QString uidPerson;
-            if (e.hasAttribute(QStringLiteral("uid"))) {
-                uidPerson = e.attribute(QStringLiteral("uid"));
+            if (e.hasAttribute(u"uid"_s)) {
+                uidPerson = e.attribute(u"uid"_s);
             }
-            if (e.hasAttribute(QStringLiteral("first-name"))) {
-                contact.setName(e.attribute(QStringLiteral("first-name")));
+            if (e.hasAttribute(u"first-name"_s)) {
+                contact.setName(e.attribute(u"first-name"_s));
             }
-            if (e.hasAttribute(QStringLiteral("last-name"))) {
-                contact.setFamilyName(e.attribute(QStringLiteral("last-name")));
+            if (e.hasAttribute(u"last-name"_s)) {
+                contact.setFamilyName(e.attribute(u"last-name"_s));
             }
-            if (e.hasAttribute(QStringLiteral("nick-name"))) {
-                contact.setNickName(e.attribute(QStringLiteral("nick-name")));
+            if (e.hasAttribute(u"nick-name"_s)) {
+                contact.setNickName(e.attribute(u"nick-name"_s));
             }
-            if (e.hasAttribute(QStringLiteral("cn"))) {
-                contact.setFormattedName(e.attribute(QStringLiteral("cn")));
+            if (e.hasAttribute(u"cn"_s)) {
+                contact.setFormattedName(e.attribute(u"cn"_s));
             }
             QStringList uidAddress;
             for (QDomElement addressElement = e.firstChildElement(); !addressElement.isNull(); addressElement = addressElement.nextSiblingElement()) {
@@ -92,12 +94,12 @@ void SylpheedAddressBook::readAddressBook(const QString &filename)
                     for (QDomElement addresslist = addressElement.firstChildElement(); !addresslist.isNull(); addresslist = addresslist.nextSiblingElement()) {
                         const QString tagAddressList = addresslist.tagName();
                         if (tagAddressList == QLatin1StringView("address")) {
-                            if (addresslist.hasAttribute(QStringLiteral("email"))) {
-                                emails << addresslist.attribute(QStringLiteral("email"));
-                            } else if (addresslist.hasAttribute(QStringLiteral("alias"))) {
+                            if (addresslist.hasAttribute(u"email"_s)) {
+                                emails << addresslist.attribute(u"email"_s);
+                            } else if (addresslist.hasAttribute(u"alias"_s)) {
                                 // TODO:
-                            } else if (addresslist.hasAttribute(QStringLiteral("uid"))) {
-                                uidAddress << addresslist.attribute(QStringLiteral("uid"));
+                            } else if (addresslist.hasAttribute(u"uid"_s)) {
+                                uidAddress << addresslist.attribute(u"uid"_s);
                             }
                         } else {
                             qCDebug(SYLPHEEDPLUGIN_LOG) << " tagAddressList unknown :" << tagAddressList;
@@ -111,10 +113,10 @@ void SylpheedAddressBook::readAddressBook(const QString &filename)
                          attributelist = attributelist.nextSiblingElement()) {
                         const QString tagAttributeList = attributelist.tagName();
                         if (tagAttributeList == QLatin1StringView("attribute")) {
-                            if (attributelist.hasAttribute(QStringLiteral("name"))) {
-                                const QString name = attributelist.attribute(QStringLiteral("name"));
+                            if (attributelist.hasAttribute(u"name"_s)) {
+                                const QString name = attributelist.attribute(u"name"_s);
                                 const QString value = attributelist.text();
-                                contact.insertCustom(QStringLiteral("KADDRESSBOOK"), name, value);
+                                contact.insertCustom(u"KADDRESSBOOK"_s, name, value);
                             }
                         } else {
                             qCDebug(SYLPHEEDPLUGIN_LOG) << "tagAttributeList not implemented " << tagAttributeList;
@@ -129,10 +131,10 @@ void SylpheedAddressBook::readAddressBook(const QString &filename)
             } else {
                 qCDebug(SYLPHEEDPLUGIN_LOG) << " problem uidPerson already stored" << uidPerson;
             }
-            addImportContactNote(contact, QStringLiteral("Sylpheed"));
+            addImportContactNote(contact, u"Sylpheed"_s);
             createContact(contact);
         } else if (tag == QLatin1StringView("group")) {
-            QString name = e.attribute(QStringLiteral("name"));
+            QString name = e.attribute(u"name"_s);
             KContacts::ContactGroup group(name);
             // TODO: create Group
             for (QDomElement groupElement = e.firstChildElement(); !groupElement.isNull(); groupElement = groupElement.nextSiblingElement()) {
@@ -143,11 +145,11 @@ void SylpheedAddressBook::readAddressBook(const QString &filename)
                         if (tagMemberList == QLatin1StringView("member")) {
                             QString pid;
                             QString eid;
-                            if (memberlist.hasAttribute(QStringLiteral("pid"))) {
-                                pid = memberlist.attribute(QStringLiteral("pid"));
+                            if (memberlist.hasAttribute(u"pid"_s)) {
+                                pid = memberlist.attribute(u"pid"_s);
                             }
-                            if (memberlist.hasAttribute(QStringLiteral("eid"))) {
-                                eid = memberlist.attribute(QStringLiteral("eid"));
+                            if (memberlist.hasAttribute(u"eid"_s)) {
+                                eid = memberlist.attribute(u"eid"_s);
                             }
                             if (!pid.isEmpty() && !eid.isEmpty()) {
                                 // TODO
